@@ -22,6 +22,10 @@ def iboot_command():
         pack_model.build_docker()
         return
 
+    if cmd == 'compile_core':
+        pack_model.compile_core()
+        return
+
     if cmd == 'onboarding':
         onboarding.onboarding()
         return
